@@ -90,7 +90,11 @@ int maxdot_meandot(PyObject *self, PyObject *args)
                     counter++;
                 }
             }
-            cout[i][j] = mean/(double)counter;
+            if (counter == 0) {
+                cout[i][j] = mean/(double)counter;
+            } else {
+                cout[i][j] = 0;
+            }
         }
     }
     
